@@ -710,7 +710,7 @@ class DelayedArgument(LazyEvaluation):
                 bounds = sliceobj(region, data, range=True)
             if bounds.step:
                 raise ValueError('Step size is not supported for file slices.')
-            with path.open('rb') as stream:
+            with open(path, 'rb') as stream:
                 stream.seek(bounds.start or 0)
                 return stream.read(bounds.stop)
         try:
@@ -721,7 +721,7 @@ class DelayedArgument(LazyEvaluation):
             return read()
         except FileNotFoundError:
             raise ArgumentTypeError(F'File not found: {pattern}')
-        except ParserVariableMissing:
+        except Exception:
             return read
 
     @handler.register('range', final=True)
@@ -1209,8 +1209,6 @@ class DelayedNumSeqArgument(DelayedArgument):
                         F'The first item {top!r} of the iterable computed from {self.expression} was not an integer.')
                 return rewind()
             else:
-                if not all(isinstance(t, int) for t in value):
-                    raise ArgumentTypeError(F'Not all elements of {value!r}, computed from {self.expression}, are integers.')
                 return value
         if isinstance(value, float):
             tmp = int(value)
