@@ -177,6 +177,7 @@ from typing import (
     List,
     Optional,
     Callable,
+    ClassVar,
     Tuple,
     Any,
     ByteString,
@@ -1227,14 +1228,15 @@ class Unit(UnitBase, abstract=True):
     """
     Arg = Arg
 
-    optional_dependencies: Optional[Set[str]] = None
     required_dependencies: Optional[Set[str]] = None
+    optional_dependencies: Optional[Dict[str, Set[str]]] = None
 
     @staticmethod
-    def Requires(distribution: str, optional: bool = True):
+    def Requires(distribution: str, *_buckets: str):
+
         class Requirement(requirement):
-            dependency = distribution
-            required = not optional
+            dependency: ClassVar[str] = distribution
+            required: ClassVar[bool] = not _buckets
 
             def __init__(self, importer: Callable):
                 super().__init__(importer)
@@ -1243,15 +1245,16 @@ class Unit(UnitBase, abstract=True):
             def __set_name__(self, unit: Type[Unit], name: str):
                 if self.required:
                     bucket = unit.required_dependencies
+                    if bucket is None:
+                        unit.required_dependencies = bucket = set()
+                    buckets = [bucket]
                 else:
-                    bucket = unit.optional_dependencies
-                if bucket is None:
-                    bucket = set()
-                    if self.required:
-                        unit.required_dependencies = bucket
-                    else:
-                        unit.optional_dependencies = bucket
-                bucket.add(self.dependency)
+                    optmap = unit.optional_dependencies
+                    if optmap is None:
+                        unit.optional_dependencies = optmap = {}
+                    buckets = [optmap.setdefault(name, set()) for name in _buckets]
+                for bucket in buckets:
+                    bucket.add(self.dependency)
 
             def __get__(self, unit: Optional[Type[Unit]], tp: Optional[Type[Executable]] = None):
                 if self.module is not None:
@@ -1259,7 +1262,10 @@ class Unit(UnitBase, abstract=True):
                 try:
                     self.module = module = self.fget()
                 except ImportError as E:
-                    args = unit.optional_dependencies or ()
+                    deps = unit.optional_dependencies or {}
+                    args = set()
+                    for v in deps.values():
+                        args.update(v)
                     raise RefineryImportMissing(self.dependency, *args) from E
                 except Exception as E:
                     raise AttributeError(F'module import for distribution "{distribution}" failed: {E!s}')
@@ -1485,7 +1491,7 @@ class Unit(UnitBase, abstract=True):
         except Exception:
             pass
 
-    def __neg__(self):
+    def __neg__(self) -> Unit:
         pipeline = []
         cursor = self
         while isinstance(cursor, Unit):
@@ -1550,7 +1556,7 @@ class Unit(UnitBase, abstract=True):
         ...
 
     @overload
-    def __or__(self, stream: Type[...]) -> bytearray:
+    def __or__(self, stream: Type[bytearray]) -> bytearray:
         ...
 
     @overload
@@ -1842,7 +1848,10 @@ class Unit(UnitBase, abstract=True):
             gp = argument.group
             if gp not in groups:
                 groups[gp] = argp.add_mutually_exclusive_group()
-            groups[gp].add_argument @ argument
+            try:
+                groups[gp].add_argument @ argument
+            except Exception:
+                raise RefineryCriticalException(F'Failed to queue argument: {argument!s}')
 
         return argp
 
