@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from Crypto.Cipher import DES3
+from Cryptodome.Cipher import DES3
 
 from refinery.units.crypto.cipher import StandardBlockCipherUnit
 from refinery.lib.crypto import PyCryptoFactoryWrapper
