@@ -78,10 +78,19 @@ def decompile_buffer(buffer: Union[Code, ByteString], file_name: Optional[str] =
     if not isinstance(buffer, Code):
         codes = list(extract_code_from_buffer(buffer, file_name))
     for code in codes:
-        for name, engine in {
-            'decompyle3': main._decompyle3,
-            'uncompyle6': main._uncompyle6,
-        }.items():
+        engines = {}
+        for e in ['decompyle3', 'uncompyle6']:
+            try:
+                dc = getattr(main, F'_{e}')
+                if isinstance(dc, property):
+                    dc = dc.fget()
+            except ImportError:
+                errors += F'# The decompiler {dc} is not installed.\n'
+            else:
+                engines['decompyle3'] = dc
+        if not engines:
+            errors += '# (all missing, install one of the above to enable decompilation)'
+        for name, engine in engines.items():
             with io.StringIO(newline='') as output, NoLogging(NoLogging.Mode.ALL):
                 try:
                     engine.main.decompile(
@@ -190,8 +199,11 @@ class PYZ(Struct):
         if signature != self.MagicSignature:
             raise ValueError('invalid magic')
         magic = bytes(reader.read(4))
-        with contextlib.suppress(KeyError):
-            version = xtpyi._xdis.magics.versions[magic]
+        with contextlib.suppress(KeyError, AttributeError):
+            xdis = xtpyi._xdis
+            if isinstance(xdis, property):
+                xdis = xdis.fget()
+            version = xdis.magics.versions[magic]
         vtuple = version2tuple(version)
         padding_size = 4
         if vtuple >= (3, 3):
@@ -211,17 +223,20 @@ class PYZ(Struct):
             toc = marshal.loads(toc_data)
         except Exception as error:
             if MAGIC_NUMBER != self.magic[:4]:
-                _ord = xtpyi._xdis.marsh.Ord
-                xtpyi._xdis.marsh.Ord = ord  # monkey-patch workaround for bug in xdis
+                xdis = xtpyi._xdis
+                if isinstance(xdis, property):
+                    xdis = xdis.fget()
+                _ord = xdis.marsh.Ord
+                xdis.marsh.Ord = ord  # monkey-patch workaround for bug in xdis
                 try:
-                    toc = xtpyi._xdis.marsh.load(
+                    toc = xdis.marsh.load(
                         MemoryFile(self.data), self.version)
                 except Exception:
                     pass
                 else:
                     error = None
                 finally:
-                    xtpyi._xdis.marsh.Ord = _ord
+                    xdis.marsh.Ord = _ord
             if error is not None:
                 raise error
 
@@ -501,7 +516,7 @@ class xtpyi(ArchiveUnit):
             user_code=user_code,
         )
 
-    @ArchiveUnit.Requires('xdis', optional=False)
+    @ArchiveUnit.Requires('xdis', 'arc', 'python', 'extended')
     def _xdis():
         import xdis.load
         import xdis.magics
@@ -532,13 +547,13 @@ class xtpyi(ArchiveUnit):
         import xdis.std
         return xdis
 
-    @ArchiveUnit.Requires('uncompyle6', optional=False)
+    @ArchiveUnit.Requires('uncompyle6', 'arc', 'python', 'extended')
     def _uncompyle6():
         import uncompyle6
         import uncompyle6.main
         return uncompyle6
 
-    @ArchiveUnit.Requires('decompyle3', optional=False)
+    @ArchiveUnit.Requires('decompyle3', 'arc', 'python')
     def _decompyle3():
         import decompyle3
         import decompyle3.main
