@@ -1,12 +1,13 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 from __future__ import annotations
-from typing import Union
+from typing import Union, Optional
 
 import json
 
 from refinery.units.formats import PathExtractorUnit, UnpackResult, Unit
 from refinery.lib.meta import is_valid_variable_name
+from refinery.lib.patterns import checks
 
 
 class xtjson(PathExtractorUnit):
@@ -18,15 +19,12 @@ class xtjson(PathExtractorUnit):
     def unpack(self, data):
 
         def crawl(path, cursor):
-            if isinstance(cursor, (dict, list)) and path:
-                path = F'{path}/'
             if isinstance(cursor, dict):
                 for key, value in cursor.items():
-                    yield from crawl(F'{path}{key}', value)
+                    yield from crawl(F'{path}/{key}', value)
             elif isinstance(cursor, list):
-                width = len(F'{len(cursor)-1:d}')
                 for key, value in enumerate(cursor):
-                    yield from crawl(F'{path}#{key:0{width}d}', value)
+                    yield from crawl(F'{path}({key:d})', value)
             if path:
                 yield path, cursor, cursor.__class__.__name__
 
@@ -39,6 +37,10 @@ class xtjson(PathExtractorUnit):
                 return dumped.encode(self.codec)
             yield UnpackResult(path, extract, type=typename)
 
+    @classmethod
+    def handles(self, data: bytearray) -> Optional[bool]:
+        return bool(checks.json.fullmatch(data))
+
 
 class xj0(Unit):
     """
@@ -50,8 +52,8 @@ class xj0(Unit):
     def __init__(
         self,
         key: Unit.Arg.Binary(help='Optional key of a value to become the main body of the chunk.') = None,
-        raw: Unit.Arg('-r', group='META', help='Do not extract any other fields as metadata.') = False,
-        all: Unit.Arg('-a', group='META', help='Extract all other fields as metadata.') = False
+        raw: Unit.Arg.Switch('-r', group='META', help='Do not extract any other fields as metadata.') = False,
+        all: Unit.Arg.Switch('-a', group='META', help='Extract all other fields as metadata.') = False
     ):
         super().__init__(key=key, raw=raw, all=all)
 
@@ -102,4 +104,4 @@ class xjl(Unit):
         except AttributeError:
             it = doc
         for item in it:
-            yield json.dumps(item).encode(self.codec)
+            yield json.dumps(item, indent=4).encode(self.codec)
