@@ -22,7 +22,7 @@ class doctxt(Unit):
     Extract text from Word Documents
     """
 
-    @Unit.Requires('olefile', optional=False)
+    @Unit.Requires('olefile', 'formats', 'office', 'extended')
     def _olefile():
         import olefile
         return olefile
@@ -43,6 +43,8 @@ class doctxt(Unit):
             self.log_debug(F'trying to extract as {filetype}')
             try:
                 result = extractor(data)
+            except ImportError:
+                raise
             except Exception as error:
                 self.log_info(F'failed extractring as {filetype}: {error!s}')
             else:
