@@ -18,6 +18,6 @@ class n40(Unit):
         try:
             data = b16decode(data, casefold=True)
         except Error:
-            self.log_warn('Input was not hex-encoded; ignoring this step.')
+            self.log_info('Input was not hex-encoded; ignoring this step.')
         mask = data[1:] | xor(self.args.key) | bytearray
         return bytearray(0xFF + b - a if b <= a else b - a for a, b in zip(data, mask))
